@@ -12,18 +12,19 @@ from rb.utils.rblogger import Logger
 
 logger = Logger.get_logger()
 
-class Contribution(Block):
+SIGNIFICANT_LIMIT = 5
+
+class Contribution(TextElement):
 
     def __init__(self, lang: Lang, text: str,
         participant: Participant,
         parent_contribution: "Contribution",
         timestamp: int,
-        depth: int = TextElementType.DOC.value,
+        depth: int = TextElementType.BLOCK.value,
         container: TextElement = None,
         ):
-        Block.__init__(self, lang=lang, text=text,
-                             depth=depth, container=container)
-
+        
+        super().__init__(lang=lang, text=text, depth=depth, container=container)
         self.parent_contribution = parent_contribution
         self.participant = participant
         self.timestamp = timestamp
@@ -42,6 +43,9 @@ class Contribution(Block):
     def get_timestamp(self) -> int:
     	return self.timestamp
 
+    def is_significant(self):
+        return len(self.get_words()) >= SIGNIFICANT_LIMIT
+
     def __str__(self):
         return NotImplemented
 
