@@ -1,3 +1,4 @@
+import json
 from typing import List, Dict
 import csv
 from dateutil import parser
@@ -14,9 +15,10 @@ from rb.core.cscl.cscl_indices import CsclIndices
 from rb.cna.cna_graph import CnaGraph
 from rb.similarity.vector_model_factory import create_vector_model
 from rb.similarity.vector_model import VectorModelType
-from rb.processings.cscl.participant_evaluation import evaluate_interaction, evaluate_involvement, evaluate_used_concepts, perform_sna
 
 from rb.utils.rblogger import Logger
+from rb.processings.cscl.community_processing import compute_sna_metrics, determine_participant_contributions, determine_participation
+from rb.processings.cscl.participant_evaluation import evaluate_interaction, evaluate_involvement, evaluate_used_concepts, perform_sna
 
 logger = Logger.get_logger()
 
@@ -27,6 +29,26 @@ TIMESTAMP_KEY = 'timestamp'
 TEXT_KEY = 'text'
 USER_KEY = 'user'
 
+def get_json_from_json_file(filename: str) -> Dict:
+	conversation_thread = dict()
+	contribution_list = []
+
+	with open(filename, "rt", encoding='utf-8') as json_file:
+		contribution_list_json = json.load(json_file)
+		for cnt in contribution_list_json:
+			contribution = {
+				ID_KEY: cnt['genid'],
+				PARENT_ID_KEY: cnt["ref"],
+				TIMESTAMP_KEY: int(float(cnt['time'])),
+				USER_KEY: cnt["nickname"],
+				TEXT_KEY: cnt["text"],
+			}
+			contribution_list.append(contribution)
+
+	conversation_thread[CONTRIBUTIONS_KEY] = contribution_list
+
+	return conversation_thread
+
 def get_json_from_csv(filename: str) -> Dict:
 	conversation_thread = dict()
 	contribution_list = []
@@ -100,6 +122,7 @@ def load_from_xml(lang: Lang, filename: str) -> Dict:
 
 		return {CONTRIBUTIONS_KEY: contributions}
 
+
 def compute_indices(conv: Conversation):
 	participant_list = conv.get_participants()
 	names = list(map(lambda p: p.get_id(), participant_list))
@@ -119,13 +142,13 @@ def compute_indices(conv: Conversation):
 	for p in participant_list:
 		print('Printing for participant ' + p.get_id())
 
-		print(p.get_index(CsclIndices.SCORE))
-		print(p.get_index(CsclIndices.NO_NOUNS))
-		print(p.get_index(CsclIndices.NO_VERBS))
-		print(p.get_index(CsclIndices.NO_CONTRIBUTION))
-		print(p.get_index(CsclIndices.SOCIAL_KB))
-		print(p.get_index(CsclIndices.INDEGREE))
-		print(p.get_index(CsclIndices.OUTDEGREE))
+		print("SCORE  " + str(p.get_index(CsclIndices.SCORE)))
+		print("NO_NOUNS " + str(p.get_index(CsclIndices.NO_NOUNS)))
+		print("NO_VERBS " + str(p.get_index(CsclIndices.NO_VERBS)))
+		print("NO_CONTRIBUTION " + str(p.get_index(CsclIndices.NO_CONTRIBUTION)))
+		print("SOCIAL_KB " + str(p.get_index(CsclIndices.SOCIAL_KB)))
+		print("INDEGREE " + str(p.get_index(CsclIndices.INDEGREE)))
+		print("OUTDEGREE " + str(p.get_index(CsclIndices.OUTDEGREE)))
 
 		print('---------------------')
 
@@ -134,9 +157,66 @@ def compute_indices(conv: Conversation):
 			print('Score for ' + n1 + ' ' + n2 + ' is:')
 			print(conv.get_score(n1, n2))
 
+
+def test_community_processing(community: Community):
+	print('Testing Community Processing')
+
+	participant_list = community.get_participants()
+	names = list(map(lambda p: p.get_id(), participant_list))
+
+	print('Participants are:')
+	print(names)
+
+	print('Begin computing indices')
+
+	determine_participant_contributions(community)
+	determine_participation(community)
+	compute_sna_metrics(community)
+
+	print('Finished computing indices')
+
+	for p in participant_list:
+		print('Printing for participant ' + p.get_id())
+
+		print(p.get_index(CsclIndices.SCORE))
+		print(p.get_index(CsclIndices.NO_NOUNS))
+		print(p.get_index(CsclIndices.NO_VERBS))
+		print(p.get_index(CsclIndices.NO_CONTRIBUTION))
+		print(p.get_index(CsclIndices.SOCIAL_KB))
+		print(p.get_index(CsclIndices.INDEGREE))
+		print(p.get_index(CsclIndices.OUTDEGREE))
+		print(p.get_index(CsclIndices.NO_NEW_THREADS))
+		print(p.get_index(CsclIndices.NEW_THREADS_OVERALL_SCORE))
+		print(p.get_index(CsclIndices.NEW_THREADS_CUMULATIVE_SOCIAL_KB))
+		print(p.get_index(CsclIndices.AVERAGE_LENGTH_NEW_THREADS))
+
+
+		print('---------------------')
+
+	for n1 in names:
+		for n2 in names:
+			print('Score for ' + n1 + ' ' + n2 + ' is:')
+			print(community.get_score(n1, n2))
+
 def main():
+	# Test community processing - English discussion csv
+	conv_thread = []
+	for i in range(1, 20):
+		conversation = get_json_from_json_file("./jsons/conversation_" + str(i) + ".json")
+		conv_thread.append(conversation)
+
+	community = Community(lang=Lang.EN, container=None, community=conv_thread)
+	en_coca_word2vec = create_vector_model(Lang.EN, VectorModelType.from_str("word2vec"), "coca")
+	community.graph = CnaGraph(docs=[community], models=[en_coca_word2vec])
+
+	conv = community.get_conversations()[0]
+	conv.container.graph = CnaGraph(docs=[conv], models=[en_coca_word2vec])
+	compute_indices(conv)
+	# test_community_processing(community)
+
 	# Test for English discussion CSV
 
+	'''
 	print('Testing English CSV')
 
 	conv_thread = parse_large_csv('./thread.csv')
@@ -148,6 +228,7 @@ def main():
 	conv = community.get_conversations()[0]
 
 	compute_indices(conv)
+	'''
 
 	# Test for French discussion XML
 
@@ -155,8 +236,8 @@ def main():
 
 	print('Testing French XML')
 
-	conv_thread = CsvParser.load_from_xml(Lang.FR, './conpa-MEEF-anonyme.xml')
-
+	conv_thread = load_from_xml(Lang.FR, './conpa-MEEF-anonyme.xml')
+	
 	community = Community(lang=Lang.FR, container=None, community=[conv_thread])
 	fr_coca_word2vec = create_vector_model(Lang.FR, VectorModelType.from_str("word2vec"), "coca")
 	community.graph = CnaGraph(docs=[community], models=[fr_coca_word2vec])
