@@ -1,17 +1,19 @@
-from os import listdir
-from os.path import isdir, isfile, join
-from typing import Iterable, List
-
+from gensim.models import Word2Vec 
 import spacy
-from gensim.models import Word2Vec
-from nltk.tokenize import WordPunctTokenizer, sent_tokenize
+from typing import List, Iterable
+from nltk.tokenize import sent_tokenize, WordPunctTokenizer
+from os.path import isdir, isfile, join
+from os import listdir
 from rb.core.lang import Lang
 from rb.similarity.vector_model_factory import VectorModelType
+
 from spacy.lang.ro.lemmatizer import LOOKUP
+#from spacy.lang.ro.lex_attrs import words
 
-from googletrans import Translator
-
-translator = Translator()
+# nlp = spacy.load('en_core_web_sm')
+# nlp.remove_pipe('tagger')
+# nlp.remove_pipe('parser')
+# nlp.remove_pipe('ner')
 
 def split_sentences(fileName: str) -> Iterable[List[str]]:
     # sentences = []
@@ -85,10 +87,6 @@ def str_to_vmodel(s: str) -> VectorModelType:
         return VectorModelType.WORD2VEC
     return VectorModelType.WORD2VEC
 
-def detect_lang(text: str) -> Lang:
-    prediction = translator.detect(text)
-    return str_to_lang(prediction.lang)
-
 if __name__ == "__main__":
     pass
     # with open("dict_ro.txt", "wt") as out:
@@ -96,3 +94,4 @@ if __name__ == "__main__":
     #     all_words = sorted(list(all_words))
     #     for word in all_words:
     #         out.write(word + "\n")
+
